data_two_action_games: Data from the two-action games
Description
This is the choice data from Kuelpmann and Kuzmics (2022) for the two-action games, i.e., Hawk-Dove and Matching Pennies.
For an explanation of the different treatments and the games, please refer to the paper.
Usage
data_two_action_games
Arguments
Format
rows
actions
columns
treatments
cells
number of subjects who chose each action on each treatment