Learn R Programming

oottest (version 0.9.1)

predictions_three_action_games: Predictions for the three-action games

Description

These are the prediction of every theory considered in Kuelpmann and Kuzmics (2022) for the three-action games. For a explanation of the different theories, treatments and the games, please refer to the paper.

Usage

predictions_three_action_games

Arguments

Format

rows

predicted probabilities of actions

columns

treatments

tables

different theories

cells

probability of choosing an action on each treatment depending on the theory

...